===============================
shardgather
===============================

.. image:: https://badge.fury.io/py/shardgather.png
    :target: http://badge.fury.io/py/shardgather
    
.. image:: https://travis-ci.org/kevinjqiu/shardgather.png?branch=master
        :target: https://travis-ci.org/kevinjqiu/shardgather

.. image:: https://pypip.in/d/shardgather/badge.png
        :target: https://crate.io/packages/shardgather?version=latest


* Free software: BSD license
* Documentation: http://shardgather.rtfd.org.

Features
--------

* Executing SQL query against sharded databases (databases of of the same schema set)
* Render the result in different formats:
  * table
  * csv
  * human
* Interactive mode allows you manipulate the gathered data in a Python shell

Installation
------------

See :doc:`installation.rst`


Usage
-----

See :doc:`usage.rst`
